==> webgui_7.9.33.orig.tar.gz: WebGUI/lib/WebGUI/i18n/Dutch/Asset_StockData.pm <==
package WebGUI::i18n::Dutch::Asset_StockData;
use utf8;
our $I18N = {
  '% Change' => {
    'lastUpdated' => '1231707953',
    'message' => '% verandering'
  },
  '52 Wk High' => {
    'lastUpdated' => '1231707986',
    'message' => 'Hoogste in 52 weken'
  },
  '52 Wk Low' => {
    'lastUpdated' => '1231707999',
    'message' => 'Laagste in 52 weken'
  },
  'Change' => {
    'lastUpdated' => '1231708009',
    'message' => 'Verandering'
  },
  'Close' => {
    'lastUpdated' => '1231708020',
    'message' => 'Afsluiten'
  },
  'Day High' => {
    'lastUpdated' => '1231708030',
    'message' => 'Hoogste van de dag'
  },
  'Day Low' => {
    'lastUpdated' => '1231708038',
    'message' => 'Laagste van de dag'
  },
  'Dividend' => {
    'lastUpdated' => '1231708071',
    'message' => 'Dividend'
  },
  'EPS' => {
    'lastUpdated' => '1231708088',
    'message' => 'Verdiensten per aandeel'
  },
  'Exchange' => {
    'lastUpdated' => '1231708174',
    'message' => 'Beurs'
  },
  'Last Trade' => {
    'lastUpdated' => '1231708193',
    'message' => 'Laatst verhandeld'
  },
  'Last Update' => {
    'lastUpdated' => '1230580141',
    'message' => 'Laatst bijgewerkt'
  },
  'Market Cap' => {
    'lastUpdated' => '1231708248',
    'message' => 'Marktkapitalisatie'
  },
  'Open' => {
    'lastUpdated' => '1231708271',
    'message' => 'Bij opening'
  },
  'Prev Close' => {
    'lastUpdated' => '1231708290',
    'message' => 'Sluitingswaarde'
  },
  'Stock Watch' => {
    'lastUpdated' => '1230580168',
    'message' => 'Aandelen bekijken'
  },
  'Volume' => {
    'lastUpdated' => '1231708304',
    'message' => 'Aantal'
  },
  'Yield' => {
    'lastUpdated' => '1231708315',
    'message' => 'Winst'
  },
  'add_button_label' => {
    'lastUpdated' => '1154448344',
    'message' => 'Toevoegen &gt; &gt; '
  },
  'assetName' => {
    'lastUpdated' => '1154528413',
    'message' => 'Beurscijfers'
  },
  'defaultStocks' => {
    'lastUpdated' => '1189373007',
    'message' => 'De standaard lijst van aandelen als de gebruiker er nog geen gekozen heeft. Dit is een tekst waarin elk aandeel op een nieuwe regel staat.'
  },
  'default_stock_description' => {
    'lastUpdated' => '1154529193',
    'message' => 'Voer de standaard-aandelen in die u wilt laten zien aan bezoekers en aan gebruikers die hun aandelenlijst niet hebben gepersonaliseerd. E&eacute;n aandelensymbool per regel. '
  },
  'default_stock_label' => {
    'lastUpdated' => '1154529205',
    'message' => 'Standaard-aandelen'
  },
  'default_stock_label_description' => {
    'lastUpdated' => '1225914798',
    'message' => 'Voer een lijst van standaard-aandelen in (&eacute;&eacute;n per regel).'
  },
  'delayed 20 minutes' => {
    'lastUpdated' => '1230580177',
    'message' => '20 minuten vertraagd'
  },
  'delete_confirm' => {
    'lastUpdated' => '1154529523',
    'message' => 'Weet u zeker dat u procent-tekens van uw aandelenlijst wilt verwijderen? '
  },
  'displayTemplateId' => {
    'lastUpdated' => '1189373030',
    'message' => 'De ID van het template dat gebruikt wordt om de gebruiker details over zijn aandelen te geven.'
  },
  'display_template_label' => {
    'lastUpdated' => '1154529615',
    'message' => '&#39;Laat aandelen zien&#39;-sjabloon'
  },
  'display_template_label_description' => {
    'lastUpdated' => '1154530652',
    'message' => '<p>Kies een sjabloon-formulier uit de lijst om de weergave voor afzonderlijke aandelen te lay-outen. Aandelenlijst-weergavesjablonen gebruiken sjablonen met naamruimte &#39;StockList/Display&#39;. </p>'
  },
  'editUrl' => {
    'lastUpdated' => '1154532209',
    'message' => 'De URL naar de pagina waar gebruikers hun aandelen naar wens kunnen aanpassen. '
  },
  'edit_title' => {
    'lastUpdated' => '1154533968',
    'message' => 'Bewerk Aandelenlijst '
  },
  'extrasFolder' => {
    'lastUpdated' => '1154539804',
    'message' => 'De URL naar de map met extra&#39;s, die css-bestanden en -beelden bevat, gebruikt door de aandelenlijst-applicatie. '
  },
  'failover' => {
    'lastUpdated' => '1189373060',
    'message' => 'Een voorwaardelijke variabele die aangeeft of de Aandelenticker is ingesteld op \'failover\'.'
  },
  'failover_description' => {
    'lastUpdated' => '1154540209',
    'message' => '<p>Als deze optie als &#39;ja&#39; is gemarkeerd, zullen alle beschikbare aandelenbronnen worden doorzocht (te beginnen met de primaire bron). Indien gemarkeerd &#39;nee&#39;, wordt alleen de primair geselecteerde bron doorzocht. Dit zal het aantal beschikbare aandelen voor uw gebruikers terugbrengen, maar de prestatie van aandelen-toegang zal juist zeer toenemen.</p>'
  },
  'failover_label' => {
    'lastUpdated' => '1154540658',
    'message' => '<p>Gebruik meervoudige bronnen</p>'
  },
  'failover_label_description' => {
    'lastUpdated' => '1170691905',
    'message' => 'Ja kiezen geeft aan dat alle beschikbare internetbronnen zullen worden doorzocht om elk aandeel te vinden. Nee kiezen beperkt de zoekactie tot uw primaire bron. Hierdoor wordt de prestatie van zoekacties sterk verbeterd, maar blijven uw gebruikers beperkt tot aandelen die slechts in een bron beschikbaar zijn.'
  },
  'finish_button_label' => {
    'lastUpdated' => '1154610329',
    'message' => 'Voltooien'
  },
  'help_stock_list_display_template' => {
    'lastUpdated' => '1249909663',
    'message' => 'Sjabloon aandelenlijst tonen'
  },
  'help_stock_list_template' => {
    'lastUpdated' => '1190025438',
    'message' => 'Aandelenlijst-sjabloon'
  },
  'isVisitor' => {
    'lastUpdated' => '1253793675',
    'message' => 'Of de huidige gebruiker wel of geen bezoeker is. Dit komt terug als waar als de gebruiker authentiek verklaard is tegen het systeem. '
  },
  'lastUpdate.default' => {
    'lastUpdated' => '1154693733',
    'message' => 'standaard datum- en tijd-formaat voor de datum en het tijdstip waarop aandelen werden bijgewerkt door de terugkerende bronnen '
  },
  'lastUpdate.intl' => {
    'lastUpdated' => '1154693751',
    'message' => 'internationaal datum- en tijd-formaat voor de datum en het tijdstip waarop aandelen werden bijgewerkt door de terugkerende bronnen'
  },
  'lastUpdate.us' => {
    'lastUpdated' => '1154693767',
    'message' => 'VS datum- en tijd-formaat voor de datum en het tijdstip waarop aandelen werden bijgewerkt door de terugkerende bronnen'
  },
  'no_symbol' => {
    'lastUpdated' => '1154693816',
    'message' => 'Het symbool &#39;%&#39; kon niet gevonden worden in de lijst van beschikbare marktonderzoek-bronnen '
  },
  'no_symbol_error' => {
    'lastUpdated' => '1154693927',
    'message' => '&quot;U heeft geen aandelensymbool ingevoerd om toe te voegen aan uw lijst&quot; '
  },
  'source' => {
    'lastUpdated' => '1189373091',
    'message' => 'De internetlocatie die gebruikt wordt als informatiebron voor de aandeleninformatie.'
  },
  'stock data asset template variables title' => {
    'lastUpdated' => '1249909679',
    'message' => 'Sjabloon variabelen voor de Aandelenticker'
  },
  'stock.display.url' => {
    'lastUpdated' => '1154693995',
    'message' => 'Algemene URL naar de pagina die details van afzonderlijke aandelen laat zien. Aan het eind van deze URL moet een aandelensymbool worden toegevoegd. '
  },
  'stock_source' => {
    'lastUpdated' => '1154694057',
    'message' => 'Primaire bron'
  },
  'stock_source_description' => {
    'lastUpdated' => '1154694552',
    'message' => 'Kies de primaire bron om aandelen van op te halen. Dit is de eerste internetlocatie waar de applicatie zal zoeken. Als u de bron kiest die de aandelen bevat die de meerderheid van uw bezoekers bekijken, zal de prestatie van de aandelenlijst sterk toenemen.  '
  },
  'stocks.ask' => {
    'lastUpdated' => '1231708323',
    'message' => 'Vraag'
  },
  'stocks.avg_vol' => {
    'lastUpdated' => '1154694582',
    'message' => 'Gemiddeld dagelijks volume'
  },
  'stocks.bid' => {
    'lastUpdated' => '1154694591',
    'message' => 'Bod'
  },
  'stocks.cap' => {
    'lastUpdated' => '1154695602',
    'message' => 'Markt kapitalisatie'
  },
  'stocks.close' => {
    'lastUpdated' => '1154695822',
    'message' => 'Vorig slot'
  },
  'stocks.date' => {
    'lastUpdated' => '1154695846',
    'message' => 'Laatste handelsdatum (mm/dd/jjjj-formaat)'
  },
  'stocks.day_range' => {
    'lastUpdated' => '1154695940',
    'message' => 'Dag-bereik'
  },
  'stocks.div' => {
    'lastUpdated' => '1154696990',
    'message' => 'Dividend per aandeel'
  },
  'stocks.div_date' => {
    'lastUpdated' => '1154702520',
    'message' => 'Dividend betaaldatum'
  },
  'stocks.div_yield' => {
    'lastUpdated' => '1154703504',
    'message' => 'Dividend opbrengst'
  },
  'stocks.eps' => {
    'lastUpdated' => '1154703537',
    'message' => 'Opbrengsten per aandeel'
  },
  'stocks.errormsg' => {
    'lastUpdated' => '1154703728',
    'message' => 'Als succes fout is, bevat dit veld wellicht de reden '
  },
  'stocks.ex_div' => {
    'lastUpdated' => '1231708327',
    'message' => 'Ex-dividend datum'
  },
  'stocks.exchange' => {
    'lastUpdated' => '1154706297',
    'message' => 'De uitwisseling waar de informatie vandaan is gehaald'
  },
  'stocks.high' => {
    'lastUpdated' => '1154706381',
    'message' => 'Hoogste handel vandaag '
  },
  'stocks.last' => {
    'lastUpdated' => '1154706870',
    'message' => 'Laatste prijs'
  },
  'stocks.loop' => {
    'lastUpdated' => '1154706946',
    'message' => 'Loop die alle standaard- of gepersonaliseerde aandelen bevat '
  },
  'stocks.low' => {
    'lastUpdated' => '1154706968',
    'message' => 'Laagste handel vandaag'
  },
  'stocks.method' => {
    'lastUpdated' => '1154711619',
    'message' => 'De module (zoals kon worden gebruikt om te brengen) die deze informatie heeft gevonden'
  },
  'stocks.name' => {
    'lastUpdated' => '1154711703',
    'message' => 'Bedrijfs- of investeringsfonds-naam '
  },
  'stocks.nav' => {
    'lastUpdated' => '1154711784',
    'message' => 'Netto asset-waarde'
  },
  'stocks.net' => {
    'lastUpdated' => '1154711914',
    'message' => 'Netto verandering'
  },
  'stocks.net.icon' => {
    'lastUpdated' => '1154712862',
    'message' => 'Icoon voor netto verandering (omhoog, omlaag, gelijk) '
  },
  'stocks.net.isDown' => {
    'lastUpdated' => '1154712935',
    'message' => 'Netto verandering is negatief'
  },
  'stocks.net.isUp' => {
    'lastUpdated' => '1154713010',
    'message' => 'Netto verandering is positief'
  },
  'stocks.net.noChange' => {
    'lastUpdated' => '1154716615',
    'message' => 'Netto verandering is nul'
  },
  'stocks.open' => {
    'lastUpdated' => '1154716892',
    'message' => 'Opening van vandaag'
  },
  'stocks.p_change' => {
    'lastUpdated' => '1154716923',
    'message' => 'Percentage verandering ten opzichte van het slot van gisteren '
  },
  'stocks.pe' => {
    'lastUpdated' => '1231708338',
    'message' => 'P/O-ratio'
  },
  'stocks.success' => {
    'lastUpdated' => '1154717393',
    'message' => 'Heeft het aandeel succesvol informatie teruggegestuurd? '
  },
  'stocks.symbol' => {
    'lastUpdated' => '1154783321',
    'message' => 'Aandeel-symbool'
  },
  'stocks.time' => {
    'lastUpdated' => '1154783333',
    'message' => 'Laatste handelsdatum'
  },
  'stocks.volume' => {
    'lastUpdated' => '1154783349',
    'message' => 'Dag-volume'
  },
  'stocks.volume.millions' => {
    'lastUpdated' => '1154783386',
    'message' => 'Dag-volume in miljoenen'
  },
  'stocks.year_high' => {
    'lastUpdated' => '1154783406',
    'message' => '52 weken-hoogtepunt'
  },
  'stocks.year_low' => {
    'lastUpdated' => '1154784552',
    'message' => '52 weken-dieptepunt '
  },
  'stocks.year_range' => {
    'lastUpdated' => '1154784568',
    'message' => '52 weken-bereik'
  },
  'stocks.yield' => {
    'lastUpdated' => '1154784971',
    'message' => 'Opbrengst (meestal 30 dagen-gemiddelde)'
  },
  'symbol_edit_label' => {
    'lastUpdated' => '1154784992',
    'message' => 'Aandeel-symbolen toevoegen/bewerken'
  },
  'symbol_exists' => {
    'lastUpdated' => '1154785065',
    'message' => 'Het symbool &#39;%s&#39; is al in uw aandelenlijst'
  },
  'symbol_header' => {
    'lastUpdated' => '1154785907',
    'message' => 'Aandeel-symbool-lijst'
  },
  'symbol_label' => {
    'lastUpdated' => '1154786008',
    'message' => 'Aandeel-symbool'
  },
  'symbol_label_description' => {
    'lastUpdated' => '1154786165',
    'message' => 'Voer een geldig aandeel-symbool in. Als uw symbool niet gevonden kan worden, neem dan contact op met uw admin. Waarschijnlijk beperkt uw site zich tot aandelen van een bepaalde markt (VS, Europese markt, enzovoorts) '
  },
  'templateId' => {
    'lastUpdated' => '1189373159',
    'message' => 'De ID van het template dat gebruikt wordt om het hoofdscherm weer te geven van dit object (asset).'
  },
  'template_label' => {
    'lastUpdated' => '1154786242',
    'message' => 'Aandelenlijs-sjabloon '
  },
  'template_label_description' => {
    'lastUpdated' => '1154786302',
    'message' => 'Kies een sjabloon uit de lijst om uw aandelenlijst te lay-outen. Elke aandelenlijst kan alleen sjablonen gebruiken met de naamruimte &#39;StockList&#39; '
  }
}
;

1;

==> webgui_7.10.29.orig.tar.gz: WebGUI/lib/WebGUI/i18n/Dutch/Asset_StockData.pm <==
package WebGUI::i18n::Dutch::Asset_StockData;
use utf8;
our $I18N = {
  '% Change' => {
    'lastUpdated' => '1231707953',
    'message' => '% verandering'
  },
  '52 Wk High' => {
    'lastUpdated' => '1231707986',
    'message' => 'Hoogste in 52 weken'
  },
  '52 Wk Low' => {
    'lastUpdated' => '1231707999',
    'message' => 'Laagste in 52 weken'
  },
  'Change' => {
    'lastUpdated' => '1231708009',
    'message' => 'Verandering'
  },
  'Close' => {
    'lastUpdated' => '1231708020',
    'message' => 'Afsluiten'
  },
  'Day High' => {
    'lastUpdated' => '1231708030',
    'message' => 'Hoogste van de dag'
  },
  'Day Low' => {
    'lastUpdated' => '1231708038',
    'message' => 'Laagste van de dag'
  },
  'Dividend' => {
    'lastUpdated' => '1231708071',
    'message' => 'Dividend'
  },
  'EPS' => {
    'lastUpdated' => '1231708088',
    'message' => 'Verdiensten per aandeel'
  },
  'Exchange' => {
    'lastUpdated' => '1231708174',
    'message' => 'Beurs'
  },
  'Last Trade' => {
    'lastUpdated' => '1231708193',
    'message' => 'Laatst verhandeld'
  },
  'Last Update' => {
    'lastUpdated' => '1230580141',
    'message' => 'Laatst bijgewerkt'
  },
  'Market Cap' => {
    'lastUpdated' => '1231708248',
    'message' => 'Marktkapitalisatie'
  },
  'Open' => {
    'lastUpdated' => '1231708271',
    'message' => 'Bij opening'
  },
  'Prev Close' => {
    'lastUpdated' => '1231708290',
    'message' => 'Sluitingswaarde'
  },
  'Stock Watch' => {
    'lastUpdated' => '1230580168',
    'message' => 'Aandelen bekijken'
  },
  'Volume' => {
    'lastUpdated' => '1231708304',
    'message' => 'Aantal'
  },
  'Yield' => {
    'lastUpdated' => '1231708315',
    'message' => 'Winst'
  },
  'add_button_label' => {
    'lastUpdated' => '1154448344',
    'message' => 'Toevoegen &gt; &gt; '
  },
  'assetName' => {
    'lastUpdated' => '1154528413',
    'message' => 'Beurscijfers'
  },
  'cache timeout help' => {
    'lastUpdated' => '1304600154',
    'message' => 'Hoe lang moeten de opgezochte waarden van aandelen bewaard worden. Let erop dat het standaard sjabloon javascript gebruikt dat vanaf de browser de data ophaalt.'
  },
  'defaultStocks' => {
    'lastUpdated' => '1189373007',
    'message' => 'De standaard lijst van aandelen als de gebruiker er nog geen gekozen heeft. Dit is een tekst waarin elk aandeel op een nieuwe regel staat.'
  },
  'default_stock_description' => {
    'lastUpdated' => '1154529193',
    'message' => 'Voer de standaard-aandelen in die u wilt laten zien aan bezoekers en aan gebruikers die hun aandelenlijst niet hebben gepersonaliseerd. E&eacute;n aandelensymbool per regel. '
  },
  'default_stock_label' => {
    'lastUpdated' => '1154529205',
    'message' => 'Standaard-aandelen'
  },
  'default_stock_label_description' => {
    'lastUpdated' => '1225914798',
    'message' => 'Voer een lijst van standaard-aandelen in (&eacute;&eacute;n per regel).'
  },
  'delayed 20 minutes' => {
    'lastUpdated' => '1230580177',
    'message' => '20 minuten vertraagd'
  },
  'delete_confirm' => {
    'lastUpdated' => '1154529523',
    'message' => 'Weet u zeker dat u procent-tekens van uw aandelenlijst wilt verwijderen? '
  },
  'displayTemplateId' => {
    'lastUpdated' => '1189373030',
    'message' => 'De ID van het template dat gebruikt wordt om de gebruiker details over zijn aandelen te geven.'
  },
  'display_template_label' => {
    'lastUpdated' => '1154529615',
    'message' => '&#39;Laat aandelen zien&#39;-sjabloon'
  },
  'display_template_label_description' => {
    'lastUpdated' => '1154530652',
    'message' => '<p>Kies een sjabloon-formulier uit de lijst om de weergave voor afzonderlijke aandelen te lay-outen. Aandelenlijst-weergavesjablonen gebruiken sjablonen met naamruimte &#39;StockList/Display&#39;. </p>'
  },
  'editUrl' => {
    'lastUpdated' => '1154532209',
    'message' => 'De URL naar de pagina waar gebruikers hun aandelen naar wens kunnen aanpassen. '
  },
  'edit_title' => {
    'lastUpdated' => '1154533968',
    'message' => 'Bewerk Aandelenlijst '
  },
  'extrasFolder' => {
    'lastUpdated' => '1154539804',
    'message' => 'De URL naar de map met extra&#39;s, die css-bestanden en -beelden bevat, gebruikt door de aandelenlijst-applicatie. '
  },
  'failover' => {
    'lastUpdated' => '1189373060',
    'message' => 'Een voorwaardelijke variabele die aangeeft of de Aandelenticker is ingesteld op \'failover\'.'
  },
  'failover_description' => {
    'lastUpdated' => '1154540209',
    'message' => '<p>Als deze optie als &#39;ja&#39; is gemarkeerd, zullen alle beschikbare aandelenbronnen worden doorzocht (te beginnen met de primaire bron). Indien gemarkeerd &#39;nee&#39;, wordt alleen de primair geselecteerde bron doorzocht. Dit zal het aantal beschikbare aandelen voor uw gebruikers terugbrengen, maar de prestatie van aandelen-toegang zal juist zeer toenemen.</p>'
  },
  'failover_label' => {
    'lastUpdated' => '1154540658',
    'message' => '<p>Gebruik meervoudige bronnen</p>'
  },
  'failover_label_description' => {
    'lastUpdated' => '1170691905',
    'message' => 'Ja kiezen geeft aan dat alle beschikbare internetbronnen zullen worden doorzocht om elk aandeel te vinden. Nee kiezen beperkt de zoekactie tot uw primaire bron. Hierdoor wordt de prestatie van zoekacties sterk verbeterd, maar blijven uw gebruikers beperkt tot aandelen die slechts in een bron beschikbaar zijn.'
  },
  'finish_button_label' => {
    'lastUpdated' => '1154610329',
    'message' => 'Voltooien'
  },
  'help_stock_list_display_template' => {
    'lastUpdated' => '1249909663',
    'message' => 'Sjabloon aandelenlijst tonen'
  },
  'help_stock_list_template' => {
    'lastUpdated' => '1190025438',
    'message' => 'Aandelenlijst-sjabloon'
  },
  'isVisitor' => {
    'lastUpdated' => '1253793675',
    'message' => 'Of de huidige gebruiker wel of geen bezoeker is. Dit komt terug als waar als de gebruiker authentiek verklaard is tegen het systeem. '
  },
  'lastUpdate.default' => {
    'lastUpdated' => '1154693733',
    'message' => 'standaard datum- en tijd-formaat voor de datum en het tijdstip waarop aandelen werden bijgewerkt door de terugkerende bronnen '
  },
  'lastUpdate.intl' => {
    'lastUpdated' => '1154693751',
    'message' => 'internationaal datum- en tijd-formaat voor de datum en het tijdstip waarop aandelen werden bijgewerkt door de terugkerende bronnen'
  },
  'lastUpdate.us' => {
    'lastUpdated' => '1154693767',
    'message' => 'VS datum- en tijd-formaat voor de datum en het tijdstip waarop aandelen werden bijgewerkt door de terugkerende bronnen'
  },
  'no_symbol' => {
    'lastUpdated' => '1154693816',
    'message' => 'Het symbool &#39;%&#39; kon niet gevonden worden in de lijst van beschikbare marktonderzoek-bronnen '
  },
  'no_symbol_error' => {
    'lastUpdated' => '1154693927',
    'message' => '&quot;U heeft geen aandelensymbool ingevoerd om toe te voegen aan uw lijst&quot; '
  },
  'source' => {
    'lastUpdated' => '1189373091',
    'message' => 'De internetlocatie die gebruikt wordt als informatiebron voor de aandeleninformatie.'
  },
  'stock data asset template variables title' => {
    'lastUpdated' => '1249909679',
    'message' => 'Sjabloon variabelen voor de Aandelenticker'
  },
  'stock.display.url' => {
    'lastUpdated' => '1154693995',
    'message' => 'Algemene URL naar de pagina die details van afzonderlijke aandelen laat zien. Aan het eind van deze URL moet een aandelensymbool worden toegevoegd. '
  },
  'stock_source' => {
    'lastUpdated' => '1154694057',
    'message' => 'Primaire bron'
  },
  'stock_source_description' => {
    'lastUpdated' => '1154694552',
    'message' => 'Kies de primaire bron om aandelen van op te halen. Dit is de eerste internetlocatie waar de applicatie zal zoeken. Als u de bron kiest die de aandelen bevat die de meerderheid van uw bezoekers bekijken, zal de prestatie van de aandelenlijst sterk toenemen.  '
  },
  'stocks.ask' => {
    'lastUpdated' => '1231708323',
    'message' => 'Vraag'
  },
  'stocks.avg_vol' => {
    'lastUpdated' => '1154694582',
    'message' => 'Gemiddeld dagelijks volume'
  },
  'stocks.bid' => {
    'lastUpdated' => '1154694591',
    'message' => 'Bod'
  },
  'stocks.cap' => {
    'lastUpdated' => '1154695602',
    'message' => 'Markt kapitalisatie'
  },
  'stocks.close' => {
    'lastUpdated' => '1154695822',
    'message' => 'Vorig slot'
  },
  'stocks.date' => {
    'lastUpdated' => '1154695846',
    'message' => 'Laatste handelsdatum (mm/dd/jjjj-formaat)'
  },
  'stocks.day_range' => {
    'lastUpdated' => '1154695940',
    'message' => 'Dag-bereik'
  },
  'stocks.div' => {
    'lastUpdated' => '1154696990',
    'message' => 'Dividend per aandeel'
  },
  'stocks.div_date' => {
    'lastUpdated' => '1154702520',
    'message' => 'Dividend betaaldatum'
  },
  'stocks.div_yield' => {
    'lastUpdated' => '1154703504',
    'message' => 'Dividend opbrengst'
  },
  'stocks.eps' => {
    'lastUpdated' => '1154703537',
    'message' => 'Opbrengsten per aandeel'
  },
  'stocks.errormsg' => {
    'lastUpdated' => '1154703728',
    'message' => 'Als succes fout is, bevat dit veld wellicht de reden '
  },
  'stocks.ex_div' => {
    'lastUpdated' => '1231708327',
    'message' => 'Ex-dividend datum'
  },
  'stocks.exchange' => {
    'lastUpdated' => '1154706297',
    'message' => 'De uitwisseling waar de informatie vandaan is gehaald'
  },
  'stocks.high' => {
    'lastUpdated' => '1154706381',
    'message' => 'Hoogste handel vandaag '
  },
  'stocks.last' => {
    'lastUpdated' => '1154706870',
    'message' => 'Laatste prijs'
  },
  'stocks.loop' => {
    'lastUpdated' => '1154706946',
    'message' => 'Loop die alle standaard- of gepersonaliseerde aandelen bevat '
  },
  'stocks.low' => {
    'lastUpdated' => '1154706968',
    'message' => 'Laagste handel vandaag'
  },
  'stocks.method' => {
    'lastUpdated' => '1154711619',
    'message' => 'De module (zoals kon worden gebruikt om te brengen) die deze informatie heeft gevonden'
  },
  'stocks.name' => {
    'lastUpdated' => '1154711703',
    'message' => 'Bedrijfs- of investeringsfonds-naam '
  },
  'stocks.nav' => {
    'lastUpdated' => '1154711784',
    'message' => 'Netto asset-waarde'
  },
  'stocks.net' => {
    'lastUpdated' => '1154711914',
    'message' => 'Netto verandering'
  },
  'stocks.net.icon' => {
    'lastUpdated' => '1154712862',
    'message' => 'Icoon voor netto verandering (omhoog, omlaag, gelijk) '
  },
  'stocks.net.isDown' => {
    'lastUpdated' => '1154712935',
    'message' => 'Netto verandering is negatief'
  },
  'stocks.net.isUp' => {
    'lastUpdated' => '1154713010',
    'message' => 'Netto verandering is positief'
  },
  'stocks.net.noChange' => {
    'lastUpdated' => '1154716615',
    'message' => 'Netto verandering is nul'
  },
  'stocks.open' => {
    'lastUpdated' => '1154716892',
    'message' => 'Opening van vandaag'
  },
  'stocks.p_change' => {
    'lastUpdated' => '1154716923',
    'message' => 'Percentage verandering ten opzichte van het slot van gisteren '
  },
  'stocks.pe' => {
    'lastUpdated' => '1231708338',
    'message' => 'P/O-ratio'
  },
  'stocks.success' => {
    'lastUpdated' => '1154717393',
    'message' => 'Heeft het aandeel succesvol informatie teruggegestuurd? '
  },
  'stocks.symbol' => {
    'lastUpdated' => '1154783321',
    'message' => 'Aandeel-symbool'
  },
  'stocks.time' => {
    'lastUpdated' => '1154783333',
    'message' => 'Laatste handelsdatum'
  },
  'stocks.volume' => {
    'lastUpdated' => '1154783349',
    'message' => 'Dag-volume'
  },
  'stocks.volume.millions' => {
    'lastUpdated' => '1154783386',
    'message' => 'Dag-volume in miljoenen'
  },
  'stocks.year_high' => {
    'lastUpdated' => '1154783406',
    'message' => '52 weken-hoogtepunt'
  },
  'stocks.year_low' => {
    'lastUpdated' => '1154784552',
    'message' => '52 weken-dieptepunt '
  },
  'stocks.year_range' => {
    'lastUpdated' => '1154784568',
    'message' => '52 weken-bereik'
  },
  'stocks.yield' => {
    'lastUpdated' => '1154784971',
    'message' => 'Opbrengst (meestal 30 dagen-gemiddelde)'
  },
  'symbol_edit_label' => {
    'lastUpdated' => '1154784992',
    'message' => 'Aandeel-symbolen toevoegen/bewerken'
  },
  'symbol_exists' => {
    'lastUpdated' => '1154785065',
    'message' => 'Het symbool &#39;%s&#39; is al in uw aandelenlijst'
  },
  'symbol_header' => {
    'lastUpdated' => '1154785907',
    'message' => 'Aandeel-symbool-lijst'
  },
  'symbol_label' => {
    'lastUpdated' => '1154786008',
    'message' => 'Aandeel-symbool'
  },
  'symbol_label_description' => {
    'lastUpdated' => '1154786165',
    'message' => 'Voer een geldig aandeel-symbool in. Als uw symbool niet gevonden kan worden, neem dan contact op met uw admin. Waarschijnlijk beperkt uw site zich tot aandelen van een bepaalde markt (VS, Europese markt, enzovoorts) '
  },
  'templateId' => {
    'lastUpdated' => '1189373159',
    'message' => 'De ID van het template dat gebruikt wordt om het hoofdscherm weer te geven van dit object (asset).'
  },
  'template_label' => {
    'lastUpdated' => '1154786242',
    'message' => 'Aandelenlijs-sjabloon '
  },
  'template_label_description' => {
    'lastUpdated' => '1154786302',
    'message' => 'Kies een sjabloon uit de lijst om uw aandelenlijst te lay-outen. Elke aandelenlijst kan alleen sjablonen gebruiken met de naamruimte &#39;StockList&#39; '
  }
}
;

1;
